.. _extract_1d_step:

==================
Extract 1D Spectra
==================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst
   reference_image.rst

.. automodapi:: jwst.extract_1d
